@@ -85,7 +85,7 @@ def build(full=False):
     return True
 
 
-def clean():
+def clean(new_files=False):
     print("* Emptying install directory")
     _empty_dir(config.install_dir)
 
@@ -93,11 +93,7 @@ def clean():
         print("* Cleaning %s" % module.name)
 
         git_module = git.get_module(module)
-
-        if git_module.exists():
-            git_module.stash()
-
-        git_module.clean()
+        git_module.clean(new_files=new_files)
 
 
 def _ccache_reset():
@@ -122,9 +118,6 @@ def _pull_module(module, revision=None):
 
     git_module = git.get_module(module)
 
-    if git_module.exists():
-        git_module.stash()
-
     try:
         git_module.update(revision)
     except subprocess.CalledProcessError:
@@ -215,7 +208,6 @@ def _build_module(module, log=None):
     except subprocess.CalledProcessError:
         return False
 
-    git.get_module(module).stash()
     state.built_module_touch(module)
 
     return True
